"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@oclif/command");
const getDemoTabFilePaths_1 = require("../pipeline/01-getDemoTabFilePaths/getDemoTabFilePaths");
const createDemoTabFilesMeta_1 = require("../pipeline/02-createDemoTabFilesMeta/createDemoTabFilesMeta");
const createDemoTabTemplates_1 = require("../pipeline/03-createDemoTabTemplates/createDemoTabTemplates");
const replaceDemoTabTemplatesContent_1 = require("../pipeline/04-replaceDemoTabTemplatesContent/replaceDemoTabTemplatesContent");
const chalk = require('chalk');
// eslint-disable-next-line
class Generate extends command_1.Command {
    async run() {
        const { flags } = this.parse(Generate);
        this.log(chalk.blue(`Generating demos...`));
        const { demoTabCodeFilePaths, demoTabStyleFilePaths } = getDemoTabFilePaths_1.getDemoTabFilePaths();
        this.log(chalk.blue(`Found ${demoTabCodeFilePaths.length + demoTabStyleFilePaths.length} DemoTab files (code: ${demoTabCodeFilePaths.length}, style: ${demoTabStyleFilePaths.length})`));
        const demoTabFilesInfo = createDemoTabFilesMeta_1.createDemoTabFilesMeta(demoTabCodeFilePaths, demoTabStyleFilePaths, flags.prefix);
        try {
            const numOfCreatedDemoTabTemplates = await createDemoTabTemplates_1.createDemoTabTemplates(demoTabFilesInfo);
            this.log(chalk.blue(`Created ${numOfCreatedDemoTabTemplates} DemoTab templates`));
        }
        catch (err) {
            console.error('Error occurred:', err);
            this.exit();
        }
        try {
            const numOfReplacedDemoTabTemplatesContent = await replaceDemoTabTemplatesContent_1.replaceDemoTabTemplatesContent(demoTabFilesInfo);
            this.log(chalk.blue(`Content replaced in ${numOfReplacedDemoTabTemplatesContent} DemoTab templates`));
        }
        catch (err) {
            console.error('Error occurred:', err);
            this.exit();
        }
        this.log(chalk.green('Completed!'));
    }
}
exports.default = Generate;
Generate.description = 'generate demos with DemoTab';
Generate.flags = {
    prefix: command_1.flags.string({
        description: 'generate DemoTab components with filename prefix',
        default: '_',
    }),
};
